import sqlite3 from "sqlite3";

const DATABASE_PATH = "catalogue.db";

export async function getBook(id: number): Promise<DetailedBook> {
  const database = new sqlite3.Database(DATABASE_PATH, sqlite3.OPEN_READONLY);

  const sql =
    "SELECT isbn, lccn, title, subtitle, authors, edition, publisher, publish_year, publish_month, publish_location, pages, pagination, weight, last_updated, deleted FROM books WHERE id = ? ";

  const book: Promise<DetailedBook> = new Promise((resolve, reject) => {
    database.get(sql, [id], (err: Error | null, book: DetailedBook) => {
      if (err) {
        reject(err);
      }
      if (book) {
        resolve(book);
      } else {
        reject(new Error("Not a valid id"));
      }
    });
  });
  // .then((newBook) => {
  //   book = new Promise((resolve) => {
  //     resolve(newBook);
  //   });
  // })
  // .catch((err) => {
  //   console.error(err);
  // })
  // .finally(() => {
  //   database.close();
  // });

  database.close();

  return book;
}

export interface DetailedBook {
  isbn: string | null;
  lccn: string | null;
  title: string;
  authors: string | null;
  edition: string | null;
  publisher: string | null;
  publish_year: string | null;
  publish_month: string | null;
  publish_location: string | null;
  pages: string | null;
  pagination: string | null;
  weight: string | null;
  last_updated: Date | null;
  deleted: boolean | null;
}
